==> updates-0.1.3.1.tar.gz: updates-0.1.3.1/README.md <==
⤤ updates
=======

Check for updated packages in the [PyPI]().

-----

```
$ pip install updates
$ updates
```

![](http://i.imgur.com/Fp8ggoK.png)

## Thanks

**Artur Siekielski**: [Check for package updates on PyPI (works best in pip+virtualenv) (Python recipe)](http://code.activestate.com/recipes/577708-check-for-package-updates-on-pypi-works-best-in-pi/)

[**joeld**](http://stackoverflow.com/users/19104/joeld): [Print in terminal with colors using Python](http://stackoverflow.com/questions/287871/print-in-terminal-with-colors-using-python)

## Authors

**Mikhail Fedosov**

+ [http://github.com/fedosov](http://github.com/fedosov)

## License

> Copyright © 2013 Fedosov Mikhail (tbs.micle@gmail.com)

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, 
and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all copies or substantial portions 
of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS 
IN THE SOFTWARE.

==> updates-0.1.3.8.tar.gz: updates-0.1.3.8/README.md <==
⤤ updates
=======

Check for updated packages in the [PyPI]().

-----

```
$ sudo pip install updates
$ updates
```

![](http://i.imgur.com/Fp8ggoK.png)

## Thanks

**Artur Siekielski**: [Check for package updates on PyPI (works best in pip+virtualenv) (Python recipe)](http://code.activestate.com/recipes/577708-check-for-package-updates-on-pypi-works-best-in-pi/)

[**joeld**](http://stackoverflow.com/users/19104/joeld): [Print in terminal with colors using Python](http://stackoverflow.com/questions/287871/print-in-terminal-with-colors-using-python)

## Authors

**Mikhail Fedosov**

+ [http://github.com/fedosov](http://github.com/fedosov)

## License

> Copyright © 2013 Fedosov Mikhail (tbs.micle@gmail.com)

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, 
and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all copies or substantial portions 
of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS 
IN THE SOFTWARE.
